xsdata.codegen.handlers.attribute\_substitution module
======================================================

.. automodule:: xsdata.codegen.handlers.attribute_substitution
   :members:
   :undoc-members:
   :show-inheritance:
